@@ -239,6 +239,22 @@ class V1Public(NISTKey):
         d = digest.finalize()
         return h + base64url_encode(d[0:33]).decode("utf-8")
 
+    def to_peer_paserk_id(self) -> str:
+        if not self._is_secret:
+            return ""
+
+        k = self._key.public_key().public_bytes(
+            encoding=serialization.Encoding.DER,
+            format=serialization.PublicFormat.SubjectPublicKeyInfo,
+        )
+        p = "k1.public." + base64url_encode(k).decode("utf-8")
+
+        h = "k1.pid."
+        digest = hashes.Hash(hashes.SHA384())
+        digest.update((h + p).encode("utf-8"))
+        d = digest.finalize()
+        return h + base64url_encode(d[0:33]).decode("utf-8")
+
     def sign(self, payload: bytes, footer: bytes = b"", implicit_assertion: bytes = b"") -> bytes:
 
         if isinstance(self._key, RSAPublicKey):
